@@ -24,6 +24,11 @@ import Numeric
 import threading
 print "end imports"
 
+
+class AMPlayer():
+    def playtick(self, mixer, tickcount):
+        pass
+
 class AudioMixer():
 # These can be adjusted before a call to init_audio
     print "start Audio Mixer"
@@ -31,12 +36,16 @@ class AudioMixer():
     nullss=256
     sendsize=nullss
     minlatency=0
-    maxlatency=16
-    maxbytes=64
+    maxlatency=0
+    maxbytes=0
     stepsamples=2
     rate=22050
     numsources=8
 
+    players=[]
+
+    tickcount=0
+
     lock=threading.Lock()
     soundbuffers=[]
     soundqueue=[]
@@ -167,6 +176,11 @@ class AudioMixer():
         return True
 
     def need_data(self,src,length,id):
+        if id == 0:
+            self.tickcount = self.tickcount +1
+            for i in range(len(self.players)):
+                self.players[i].playtick(self, self.tickcount)
+
         self.lock.acquire()
         snd = self.soundqueue[id][0]
         if not (snd == -1):   
